@@ -4,6 +4,7 @@
 
 ################################################################################
 # CHANGE LOG (last 20 changes)
+# 28.04.2016: 'Save as' textbox expandable.
 # 26.10.2015: Added attributes.
 # 28.08.2015: Added importFrom.
 # 05.05.2015: Changed parameter 'ignoreCase' to 'ignore.case' for 'checkSubset' function.
@@ -309,7 +310,7 @@ calculateStutter_gui <- function(env=parent.frame(), savegui=NULL, debug=FALSE,
   
   glabel(text="Name for result:", container=f2)
   
-  f2_save_edt <- gedit(text="", container=f2)
+  f2_save_edt <- gedit(text="", container=f2, expand = TRUE)
   
   glabel(text=" Kit attribute:", container=f2)
   
